package xyz.thastertyn.Login;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.concurrent.TimeoutException;

import javax.security.auth.login.CredentialException;

import com.googlecode.lanterna.gui2.WindowBasedTextGUI;
import com.googlecode.lanterna.gui2.dialogs.MessageDialog;
import com.googlecode.lanterna.gui2.dialogs.MessageDialogButton;

import xyz.thastertyn.Tuples.Triplet;

public class LoginController {
	
	private WindowBasedTextGUI textGUI;
	private xyz.thastertyn.Login.CredentialsInput dialog;
	private LocalCredentials localCredentials = new LocalCredentials();
	private xyz.thastertyn.Login.Login login = new xyz.thastertyn.Login.Login();

	public LoginController(WindowBasedTextGUI textGUI)
	{
		this.textGUI = textGUI;
	}

	public void login()
	{
		String[] credentials;

		if(localCredentials.checkForExistingCredentials()) // Credentials exist
		{
			credentials = localCredentials.getCredentialsFile();
		}else{
			dialog = new CredentialsInput();
			Triplet<String, String, Boolean> data = dialog.showDialog(textGUI); // Failed to get credentials to log in, get them from user
			credentials = new String[] {data.getValue0(), data.getValue1()};

			if(data.getValue2())
			{
				localCredentials.saveCredentials(credentials);
			}
		}

		loginUsingCredentials(credentials);
	}

	private void loginUsingCredentials(String[] credentials)
	{
		try {
			login.loginJecna(credentials[0], credentials[1]);
		}catch (TimeoutException e)
		{
			MessageDialog.showMessageDialog(textGUI, "Timeout", "The attempt to connect took too long.", MessageDialogButton.Retry,
			MessageDialogButton.Abort);
		} catch (UnknownHostException e) {
			MessageDialog.showMessageDialog(textGUI, "No Internet connection",
					e.getMessage(), 
					MessageDialogButton.OK);
			login();
		} catch (CredentialException e)
		{
			MessageDialog.showMessageDialog(textGUI, "Incorrect username or password", 
			e.getMessage(), 
			MessageDialogButton.OK);
			login();
		} catch (IOException e)
		{
			MessageDialog.showMessageDialog(textGUI, "There was an error", 
			e.getMessage(), 
			MessageDialogButton.Retry);
			login();
		}
	}
}
