package xyz.thastertyn.Scrape;

import java.io.IOException;
import java.util.ArrayList;

import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import xyz.thastertyn.Tuples.Pair;
import xyz.thastertyn.Types.Choice;
import xyz.thastertyn.Types.Option;
import xyz.thastertyn.Types.Options;

public class OmluvnyList extends JecnaScrape {
	
	private ArrayList<Pair<String, String>> data;
	
	private Options schoolYearOptions;

	@Override
	public void download() throws IOException
	{
		download("https://www.spsejecna.cz/absence/student");
	}

	@Override
	public void download(Choice choice) throws IOException {
		download(String.format(
			"https://www.spsejecna.cz/absence/student?schoolYearId=%s",
			choice.getChoices().get(0)));
	}

	private void download(String url) throws IOException
	{
		data = new ArrayList<>();
		schoolYearOptions = new Options("Skolni R.");
		Document omluvnyListDokumentHTML = Downloader.download(url).get();

		Elements omluvneListy = omluvnyListDokumentHTML.select("table.absence-list").select("tbody").select("tr");

		for(Element e : omluvneListy)
		{
			String date = e.child(0).text();
			String text = e.child(1).text();

			data.add(new Pair<String, String>(date, text));
		}

		Elements options = omluvnyListDokumentHTML.select("form.listConfigure").select("select[id=schoolYearId]").select("option");

		for(Element e : options)
		{
			schoolYearOptions.addOption(new Option(e.text(), e.attr("value")));
		}
	}

	@Override
	public Options[] getOptions() {
		return new Options[] {schoolYearOptions};
	}

	public ArrayList<Pair<String, String>> getData()
	{
		return data;
	}

	@Override
	public String toString()
	{
		return (!data.isEmpty()) ? data.toString() : null;
	}

}
